///////////////////////////////////////////////////////////////////////////////
// Name:        gui.cpp
// Purpose:     Code for NeReK's Gui
// Author:      Chad Rempp
// Modified by: Chad Rempp
// Created:     05-20-03
// Copyright:   (c) 2003 Chad Rempp
// Licence:     GNU Public License (hey it's what all my friends are doing)
///////////////////////////////////////////////////////////////////////////////

#include <wx/wxprec.h>
#include <wx/glcanvas.h>
#include "ngui/ngui.h"
#include "nviz3d/nviz3d.h"
#include "nkernel/nkern_net.h"
#include "nkernel/nkern_neuron.h"

#ifndef WX_PRECOMP
   #include <wx/wx.h>
#endif

IMPLEMENT_APP(NguiApp)

///////////////////////////////////////////////////////////////////////////////
// NguiApp Class Implementation
///////////////////////////////////////////////////////////////////////////////

////////////NGuiApp OnInit Main Method///////////////////////////////////////
bool NguiApp::OnInit()
{
   NguiFrame *ngui_frame = new NguiFrame("NeReK Simulator",
       wxPoint (0,0), wxSize(450, 45), wxDEFAULT_FRAME_STYLE);
   ngui_frame->Show(TRUE);
   SetTopWindow(ngui_frame);

   return TRUE;
}

///////////////////////////////////////////////////////////////////////////////
// NguiFrame Class Implementation
///////////////////////////////////////////////////////////////////////////////

////////////NguiFrame Constructor//////////////////////////////////////////////
NguiFrame::NguiFrame(const wxString &title, const wxPoint &pos, const wxSize &size, long style)
    : wxFrame((wxFrame *) NULL, -1, title, pos, size, style)
{
    wxMenu *FileMenu = new wxMenu;
    wxMenu *NewMenu  = new wxMenu;
    wxMenuBar *MenuBar = new wxMenuBar;

    // create a menu bar
    FileMenu->Append(NguiFrame_Quit, "&Quit");
    NewMenu->Append(NguiFrame_NewPerceptron, "&Perceptron");
    NewMenu->Append(NguiFrame_NewMultiPercp, "&Multi Layer Perceptron");

    // Add it to the menu bar
    MenuBar->Append(FileMenu, "&File");
    MenuBar->Append(NewMenu,"&New");
    SetMenuBar(MenuBar);

    // Create the status bar
    CreateStatusBar(2);
    SetStatusText("Welcome To NeReK");
}

////////////NguiFrame OnQuit Method////////////////////////////////////////////
void NguiFrame::OnQuit(wxCommandEvent & WXUNUSED(event))
{
    // Force the window to close
    Close(TRUE);
}

////////////NguiFrame OnNewPerceptron Method///////////////////////////////////
void NguiFrame::OnNewPerceptron(wxCommandEvent & WXUNUSED(event))
{
    NetDialog *frm_perceptron = new NetDialog(this, -1, "Perceptron Simulator",
                               wxPoint(100,100), wxSize(125,250));
    frm_perceptron->Show();
}

////////////NguiFrame OnNewMultiPercp Method///////////////////////////////////
void NguiFrame::OnNewMultiPercp(wxCommandEvent & WXUNUSED(event))
{
}

BEGIN_EVENT_TABLE(NguiFrame, wxFrame)
   EVT_MENU(NguiFrame_Quit, NguiFrame::OnQuit)
   EVT_MENU(NguiFrame_NewPerceptron, NguiFrame::OnNewPerceptron)
   EVT_MENU(NguiFrame_NewMultiPercp, NguiFrame::OnNewMultiPercp)
END_EVENT_TABLE()

///////////////////////////////////////////////////////////////////////////////
// NetDialog Class Implementation
///////////////////////////////////////////////////////////////////////////////

////////////NetDialog Constructor//////////////////////////////////////////////
NetDialog::NetDialog(wxWindow *parent, wxWindowID id, const wxString &title,
                     const wxPoint &position, const wxSize& size, long style) :
                     wxDialog(parent, id, title, position, size, style)
{
    btn_newinput  = new wxButton(this, NetDialog_NEWINPUT_BTN, "New Input",
                                 wxPoint(10,10), wxSize(70,17));
    btn_delinput  = new wxButton(this, NetDialog_DELINPUT_BTN, "Delete Input",
                                 wxPoint(10,30), wxSize(70,17));
    btn_setwghts  = new wxButton(this, NetDialog_SETWGHTS_BTN, "Set Weights",
                                 wxPoint(10,50), wxSize(70,17));
    btn_train     = new wxButton(this, NetDialog_TRAIN_BTN, "Train",
                                 wxPoint(10,90), wxSize(70,17));
    btn_run       = new wxButton(this, NetDialog_RUN_BTN, "Run",
                                 wxPoint(10,110), wxSize(70,17));
    btn_setdesrd  = new wxButton(this, NetDialog_SETDESRD_BTN, "Set Desired",
                                 wxPoint(10,70), wxSize(70,17));
    btn_showdiag  = new wxButton(this, NetDialog_SHOWDIAG_BTN, "Show Diag",
                                 wxPoint(10,170), wxSize(70,17));
    btn_quit      = new wxButton(this, NetDialog_QUIT_BTN, "Quit",
                                 wxPoint(10,200), wxSize(70,17));
    txt_bias      = new wxTextCtrl(this, NetDialog_BIAS_TXT, "",
                                 wxPoint(90,150), wxSize(25,22));
    txt_squashval = new wxTextCtrl(this, NetDialog_SQUASHVAL_TXT, "",
                                 wxPoint(90,130), wxSize(25,22));
    stc_bias      = new wxStaticText(this, -1, "Bias Value", wxPoint(10,150));
    stc_squashval = new wxStaticText(this, -1, "Squash Value", wxPoint(10,130));
}

////////////NetDialog OnNewInput Method////////////////////////////////////////
void NetDialog::OnNewInput(wxCommandEvent &event)
{
}

////////////NetDialog OnDelInput Method////////////////////////////////////////
void NetDialog::OnDelInput(wxCommandEvent &event)
{
}

////////////NetDialog OnSetWghts Method////////////////////////////////////////
void NetDialog::OnSetWghts(wxCommandEvent &event)
{
}

////////////NetDialog OnNSetDesrd Method///////////////////////////////////////
void NetDialog::OnSetDesrd(wxCommandEvent &event)
{
}

////////////NetDialog OnTrain Method///////////////////////////////////////////
void NetDialog::OnTrain(wxCommandEvent &event)
{
}

////////////NetDialog OnRun Method/////////////////////////////////////////////
void NetDialog::OnRun(wxCommandEvent &event)
{
}

////////////NetDialog OnShowDiag Method////////////////////////////////////////
void NetDialog::OnShowDiag(wxCommandEvent &event)
{
    NvizFrame *dlg_gldiagram = new NvizFrame(this, "Network Diagram",
                               wxPoint(50,50), wxSize(450,340));
    dlg_gldiagram->Show(TRUE);
}

////////////NetDialog OnQuit Method////////////////////////////////////////////
void NetDialog::OnQuit(wxCommandEvent &event)
{
    Close(TRUE);
}

BEGIN_EVENT_TABLE(NetDialog, wxDialog)
   EVT_BUTTON(NetDialog_NEWINPUT_BTN, NetDialog::OnNewInput)
   EVT_BUTTON(NetDialog_DELINPUT_BTN, NetDialog::OnDelInput)
   EVT_BUTTON(NetDialog_SETWGHTS_BTN, NetDialog::OnSetWghts)
   EVT_BUTTON(NetDialog_TRAIN_BTN, NetDialog::OnTrain)
   EVT_BUTTON(NetDialog_RUN_BTN, NetDialog::OnRun)
   EVT_BUTTON(NetDialog_SETDESRD_BTN, NetDialog::OnSetDesrd)
   EVT_BUTTON(NetDialog_SHOWDIAG_BTN, NetDialog::OnShowDiag)
   EVT_BUTTON(NetDialog_QUIT_BTN, NetDialog::OnQuit)
END_EVENT_TABLE()


